summaryrefslogtreecommitdiffstats
path: root/models/token.go
diff options
context:
space:
mode:
authorzhuharev <hostmaster@zhuharev.ru>2016-01-06 22:41:42 +0300
committerzhuharev <hostmaster@zhuharev.ru>2016-01-06 22:41:42 +0300
commit0d5dc8a064faa978a4571f565b20959dcc49f181 (patch)
tree6e782852e3b8617e5ff804e101dc4ca730611dc1 /models/token.go
parent0cb739684096396e26595ac70817a2a05b61b443 (diff)
downloadgitea-0d5dc8a064faa978a4571f565b20959dcc49f181.tar.gz
gitea-0d5dc8a064faa978a4571f565b20959dcc49f181.zip
typo fix
Diffstat (limited to 'models/token.go')
-rw-r--r--models/token.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/models/token.go b/models/token.go
index 3bb06dc7c0..136753c324 100644
--- a/models/token.go
+++ b/models/token.go
@@ -57,8 +57,8 @@ func ListAccessTokens(uid int64) ([]*AccessToken, error) {
return tokens, nil
}
-// UpdateAccessToekn updates information of access token.
-func UpdateAccessToekn(t *AccessToken) error {
+// UpdateAccessToken updates information of access token.
+func UpdateAccessToken(t *AccessToken) error {
_, err := x.Id(t.ID).AllCols().Update(t)
return err
}